@@ -9,6 +9,7 @@ METABASE_META_FIELDS = [
     "special_type",
     "semantic_type",
     "visibility_type",
+    "display_name",
     "fk_target_table",
     "fk_target_field",
 ]
@@ -59,3 +60,13 @@ class MetabaseModel:
         return None
 
     columns: Sequence[MetabaseColumn] = field(default_factory=list)
+
+
+class _NullValue(str):
+    """Explicitly null field value."""
+
+    def __eq__(self, other: object) -> bool:
+        return other is None
+
+
+NullValue = _NullValue()
